summaryrefslogtreecommitdiffstats
path: root/kcontrol/colors
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
commit495d08bc2db58ee7fc4ea55a7158f2f61b82fc56 (patch)
treedaabcb652c07b9a17cad88ca50b63a2d91ead4a3 /kcontrol/colors
parent50001f1757f97510e80cb1990e2f2d5b00144c2a (diff)
downloadtdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.tar.gz
tdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1211357 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kcontrol/colors')
-rw-r--r--kcontrol/colors/colorscm.cpp2
-rw-r--r--kcontrol/colors/stdclient_bitmaps.h14
-rw-r--r--kcontrol/colors/widgetcanvas.cpp36
3 files changed, 26 insertions, 26 deletions
diff --git a/kcontrol/colors/colorscm.cpp b/kcontrol/colors/colorscm.cpp
index 6161198c0..bfb32c557 100644
--- a/kcontrol/colors/colorscm.cpp
+++ b/kcontrol/colors/colorscm.cpp
@@ -154,7 +154,7 @@ KColorScheme::KColorScheme(TQWidget *parent, const char *name, const TQStringLis
TQWhatsThis::add( sList, i18n("This is a list of predefined color schemes,"
" including any that you may have created. You can preview an existing"
" color scheme by selecting it from the list. The current scheme will"
- " be replaced by the selected color scheme.<p>"
+ " be tqreplaced by the selected color scheme.<p>"
" Warning: if you have not yet applied any changes you may have made"
" to the current scheme, those changes will be lost if you select"
" another color scheme.") );
diff --git a/kcontrol/colors/stdclient_bitmaps.h b/kcontrol/colors/stdclient_bitmaps.h
index 912040fe2..6b93e8481 100644
--- a/kcontrol/colors/stdclient_bitmaps.h
+++ b/kcontrol/colors/stdclient_bitmaps.h
@@ -18,7 +18,7 @@ static unsigned char close_dgray_bits[] = {
0xc0, 0x06, 0x80, 0x03, 0x80, 0x03, 0xc0, 0x06, 0x60, 0x0c, 0x30, 0x18,
0x18, 0x30, 0x08, 0x20, 0x00, 0x00, 0x00, 0x00};
-static unsigned char close_mask_bits[] = {
+static unsigned char close_tqmask_bits[] = {
0x00, 0x00, 0x00, 0x00, 0x0c, 0x30, 0x1c, 0x38, 0x38, 0x1c, 0x70, 0x0e,
0xe0, 0x07, 0xc0, 0x03, 0xc0, 0x03, 0xe0, 0x07, 0x70, 0x0e, 0x38, 0x1c,
0x1c, 0x38, 0x0c, 0x30, 0x00, 0x00, 0x00, 0x00};
@@ -34,7 +34,7 @@ static unsigned char iconify_dgray_bits[] = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
-static unsigned char iconify_mask_bits[] = {
+static unsigned char iconify_tqmask_bits[] = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x80, 0x03, 0x80, 0x02, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
@@ -49,7 +49,7 @@ static unsigned char maximize_dgray_bits[] = {
0x08, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x10,
0xf8, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
-static unsigned char maximize_mask_bits[] = {
+static unsigned char maximize_tqmask_bits[] = {
0x00, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xfc, 0x1f, 0x0c, 0x18, 0x0c, 0x18,
0x0c, 0x18, 0x0c, 0x18, 0x0c, 0x18, 0x0c, 0x18, 0x0c, 0x18, 0xfc, 0x1f,
0xfc, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
@@ -64,7 +64,7 @@ static unsigned char maximizedown_dgray_bits[] = {
0x04, 0x08, 0x04, 0x08, 0x04, 0x08, 0x04, 0x08, 0x04, 0x08, 0x04, 0x08,
0xf4, 0x0f, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00};
-static unsigned char maximizedown_mask_bits[] = {
+static unsigned char maximizedown_tqmask_bits[] = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xfc, 0x1f, 0x0c, 0x18,
0x0c, 0x18, 0x0c, 0x18, 0x0c, 0x18, 0x0c, 0x18, 0x0c, 0x18, 0x0c, 0x18,
0xfc, 0x1f, 0xfc, 0x1f, 0x00, 0x00, 0x00, 0x00};
@@ -79,7 +79,7 @@ static unsigned char menu_dgray_bits[] = {
0x00, 0x00, 0x00, 0x20, 0xf8, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
-static unsigned char menu_mask_bits[] = {
+static unsigned char menu_tqmask_bits[] = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0xfc, 0x3f, 0x04, 0x20, 0xfc, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
@@ -99,7 +99,7 @@ static unsigned char pindown_dgray_bits[] = {
0x48, 0x30, 0xc8, 0x38, 0x08, 0x1f, 0x08, 0x18, 0x10, 0x1c, 0x10, 0x0e,
0xe0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
-static unsigned char pindown_mask_bits[] = {
+static unsigned char pindown_tqmask_bits[] = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xc0, 0x1f, 0xf0, 0x3f, 0xf0, 0x3f,
0xf8, 0x3f, 0xf8, 0x3f, 0xf8, 0x1f, 0xf8, 0x1f, 0xf0, 0x1f, 0xf0, 0x0f,
0xe0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
@@ -119,7 +119,7 @@ static unsigned char pinup_dgray_bits[] = {
0x40, 0x20, 0x40, 0x20, 0x7f, 0x2a, 0x40, 0x3f, 0xc0, 0x31, 0xc0, 0x20,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
-static unsigned char pinup_mask_bits[] = {
+static unsigned char pinup_tqmask_bits[] = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x20, 0xc0, 0x31, 0xc0, 0x3f,
0xff, 0x3f, 0xff, 0x3f, 0xff, 0x3f, 0xc0, 0x3f, 0xc0, 0x31, 0xc0, 0x20,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
diff --git a/kcontrol/colors/widgetcanvas.cpp b/kcontrol/colors/widgetcanvas.cpp
index 67e68b3a3..3013321b8 100644
--- a/kcontrol/colors/widgetcanvas.cpp
+++ b/kcontrol/colors/widgetcanvas.cpp
@@ -64,7 +64,7 @@ void WidgetCanvas::paintEvent(TQPaintEvent *)
void WidgetCanvas::mousePressEvent( TQMouseEvent *me )
{
for ( int i = 0; i < MAX_HOTSPOTS; i++ )
- if ( hotspots[i].rect.contains( me->pos() ) ) {
+ if ( hotspots[i].rect.tqcontains( me->pos() ) ) {
emit widgetSelected( hotspots[i].number );
return;
}
@@ -73,7 +73,7 @@ void WidgetCanvas::mousePressEvent( TQMouseEvent *me )
void WidgetCanvas::mouseMoveEvent( TQMouseEvent *me )
{
for ( int i = 0; i < MAX_HOTSPOTS; i++ )
- if ( hotspots[i].rect.contains( me->pos() ) ) {
+ if ( hotspots[i].rect.tqcontains( me->pos() ) ) {
if ( i != currentHotspot ) {
TQString tip = tips[hotspots[i].number];
TQToolTip::remove( this );
@@ -91,7 +91,7 @@ void WidgetCanvas::dropEvent( TQDropEvent *e)
TQColor c;
if (KColorDrag::decode( e, c)) {
for ( int i = 0; i < MAX_HOTSPOTS; i++ )
- if ( hotspots[i].rect.contains( e->pos() ) ) {
+ if ( hotspots[i].rect.tqcontains( e->pos() ) ) {
emit colorDropped( hotspots[i].number, c);
return;
}
@@ -162,7 +162,7 @@ void WidgetCanvas::resetTitlebarPixmaps(const TQColor &actMed,
pact.drawPixmap(0, 0, bitmap);
pdis.drawPixmap(0, 0, bitmap);
pact.end(); pdis.end();
- bitmap = TQBitmap(16, 16, close_mask_bits, true);
+ bitmap = TQBitmap(16, 16, close_tqmask_bits, true);
close_pix->setMask(bitmap); dis_close_pix->setMask(bitmap);
minimize_pix = new TQPixmap(16, 16);
@@ -178,7 +178,7 @@ void WidgetCanvas::resetTitlebarPixmaps(const TQColor &actMed,
pact.drawPixmap(0, 0, bitmap);
pdis.drawPixmap(0, 0, bitmap);
pact.end(); pdis.end();
- bitmap = TQBitmap(16, 16, iconify_mask_bits, true);
+ bitmap = TQBitmap(16, 16, iconify_tqmask_bits, true);
minimize_pix->setMask(bitmap); dis_minimize_pix->setMask(bitmap);
maximize_pix = new TQPixmap(16, 16);
@@ -194,7 +194,7 @@ void WidgetCanvas::resetTitlebarPixmaps(const TQColor &actMed,
pact.drawPixmap(0, 0, bitmap);
pdis.drawPixmap(0, 0, bitmap);
pact.end(); pdis.end();
- bitmap = TQBitmap(16, 16, maximize_mask_bits, true);
+ bitmap = TQBitmap(16, 16, maximize_tqmask_bits, true);
maximize_pix->setMask(bitmap); dis_maximize_pix->setMask(bitmap);
normalize_pix = new TQPixmap(16, 16);
@@ -210,7 +210,7 @@ void WidgetCanvas::resetTitlebarPixmaps(const TQColor &actMed,
pact.drawPixmap(0, 0, bitmap);
pdis.drawPixmap(0, 0, bitmap);
pact.end(); pdis.end();
- bitmap = TQBitmap(16, 16, maximizedown_mask_bits, true);
+ bitmap = TQBitmap(16, 16, maximizedown_tqmask_bits, true);
normalize_pix->setMask(bitmap); dis_normalize_pix->setMask(bitmap);
menu_pix = new TQPixmap(16, 16);
@@ -226,7 +226,7 @@ void WidgetCanvas::resetTitlebarPixmaps(const TQColor &actMed,
pact.drawPixmap(0, 0, bitmap);
pdis.drawPixmap(0, 0, bitmap);
pact.end(); pdis.end();
- bitmap = TQBitmap(16, 16, menu_mask_bits, true);
+ bitmap = TQBitmap(16, 16, menu_tqmask_bits, true);
menu_pix->setMask(bitmap); dis_menu_pix->setMask(bitmap);
pinup_pix = new TQPixmap(16, 16);
@@ -247,7 +247,7 @@ void WidgetCanvas::resetTitlebarPixmaps(const TQColor &actMed,
pact.drawPixmap(0, 0, bitmap);
pdis.drawPixmap(0, 0, bitmap);
pact.end(); pdis.end();
- bitmap = TQBitmap(16, 16, pinup_mask_bits, true);
+ bitmap = TQBitmap(16, 16, pinup_tqmask_bits, true);
pinup_pix->setMask(bitmap); dis_pinup_pix->setMask(bitmap);
pindown_pix = new TQPixmap(16, 16);
@@ -268,7 +268,7 @@ void WidgetCanvas::resetTitlebarPixmaps(const TQColor &actMed,
pact.drawPixmap(0, 0, bitmap);
pdis.drawPixmap(0, 0, bitmap);
pact.end(); pdis.end();
- bitmap = TQBitmap(16, 16, pindown_mask_bits, true);
+ bitmap = TQBitmap(16, 16, pindown_tqmask_bits, true);
pindown_pix->setMask(bitmap); dis_pindown_pix->setMask(bitmap);
}
@@ -327,7 +327,7 @@ void WidgetCanvas::drawSampleWidgets()
#ifndef __osf__
TQPainter::redirect( vertScrollBar, &pm );
#endif
- vertScrollBar->repaint();
+ vertScrollBar->tqrepaint();
TQPainter::redirect( vertScrollBar, 0 );
vertScrollBar->hide();
@@ -337,8 +337,8 @@ void WidgetCanvas::drawSampleWidgets()
// Initialize the pixmap which we draw sample widgets into.
smplw.resize(width(), height());
- //smplw.fill( parentWidget()->back() );
- smplw.fill( parentWidget()->colorGroup().mid() );
+ //smplw.fill( tqparentWidget()->back() );
+ smplw.fill( tqparentWidget()->tqcolorGroup().mid() );
// Actually start painting in
@@ -567,9 +567,9 @@ void WidgetCanvas::drawSampleWidgets()
popup->setItemEnabled( id, false );
// HACK: Force Layouting
- //Sad Eagle: sizeHint() forces layouting too, and it's a lot less visible
- //popup->sizeHint(); // Breaks with Qt 3.3
- popup->resize(popup->sizeHint());
+ //Sad Eagle: tqsizeHint() forces tqlayouting too, and it's a lot less visible
+ //popup->tqsizeHint(); // Breaks with Qt 3.3
+ popup->resize(popup->tqsizeHint());
pm = TQPixmap::grabWidget( popup );
delete popup;
@@ -585,12 +585,12 @@ void WidgetCanvas::drawSampleWidgets()
// Valance
qDrawWinPanel ( &paint, 0, 0, width(), height(),
- parentWidget()->colorGroup(), TRUE, 0);
+ tqparentWidget()->tqcolorGroup(), TRUE, 0);
// Stop the painting
hotspots[ spot++ ] =
HotSpot( TQRect( 0, 0, width(), height() ), CSM_Background ); // ?
- repaint( FALSE );
+ tqrepaint( FALSE );
}